Learn R Programming

tigre (version 1.26.0)

tigre-package: tigre - Transcription factor Inference through Gaussian process Reconstruction of Expression

Description

This package implements the method of Gao et al. (2008) and Honkela et al. (2010) for Gaussian process modelling single input motif regulatory systems with time-series expression data. The method can be used to rank potential targets of transcription factors based on such data.

Arguments

Details

Package:
tigre
Type:
Package
Version:
1.12.0
Date:
2012-10-02
License:
A-GPL Version 3
For details of using the package please refer to the Vignette.

References

A.~Honkela, P.~Gao, J.~Ropponen, M.~Rattray, and N.~D.~Lawrence. tigre: Transcription factor Inference through Gaussian process Reconstruction of Expression for Bioconductor. Bioinformatics 27(7):1026-1027, 2011. DOI: 10.1093/bioinformatics/btr057.

P.~Gao, A.~Honkela, M.~Rattray, and N.~D.~Lawrence. Gaussian process modelling of latent chemical species: applications to inferring transcription factor activities. Bioinformatics 24(16):i70--i75, 2008. DOI: 10.1093/bioinformatics/btn278.

A.~Honkela, C.~Girardot, E.~H. Gustafson, Y.-H. Liu, E.~E.~M. Furlong, N.~D. Lawrence, and M.~Rattray. Model-based method for transcription factor target identification with limited data. Proc Natl Acad Sci USA 107(17):7793-7798, 2010. DOI: 10.1073/pnas.0914285107.

See Also

puma